@@ -1,12 +1,13 @@
 import py
 import tox
 import pytest
-import os, sys
-import tox._config
-from tox._venv import *  # noqa
+import os
+import sys
+import tox.config
+from tox.venv import *  # noqa
 from tox.interpreters import NoInterpreterInfo
 
-#def test_global_virtualenv(capfd):
+# def test_global_virtualenv(capfd):
 #    v = VirtualEnv()
 #    l = v.list()
 #    assert l
@@ -14,8 +15,11 @@ from tox.interpreters import NoInterpreterInfo
 #    assert not out
 #    assert not err
 #
+
+
 def test_getdigest(tmpdir):
-    assert getdigest(tmpdir) == "0"*32
+    assert getdigest(tmpdir) == "0" * 32
+
 
 def test_getsupportedinterpreter(monkeypatch, newconfig, mocksession):
     config = newconfig([], """
@@ -25,13 +29,13 @@ def test_getsupportedinterpreter(monkeypatch, newconfig, mocksession):
     venv = VirtualEnv(config.envconfigs['python'], session=mocksession)
     interp = venv.getsupportedinterpreter()
     # realpath needed for debian symlinks
-    assert py.path.local(interp).realpath() \
-      == py.path.local(sys.executable).realpath()
+    assert py.path.local(interp).realpath() == py.path.local(sys.executable).realpath()
     monkeypatch.setattr(sys, 'platform', "win32")
     monkeypatch.setattr(venv.envconfig, 'basepython', 'jython')
     py.test.raises(tox.exception.UnsupportedInterpreter,
                    venv.getsupportedinterpreter)
     monkeypatch.undo()
+    monkeypatch.setattr(venv.envconfig, "envname", "py1")
     monkeypatch.setattr(venv.envconfig, 'basepython', 'notexistingpython')
     py.test.raises(tox.exception.InterpreterNotFound,
                    venv.getsupportedinterpreter)
@@ -39,7 +43,7 @@ def test_getsupportedinterpreter(monkeypatch, newconfig, mocksession):
     # check that we properly report when no version_info is present
     info = NoInterpreterInfo(name=venv.name)
     info.executable = "something"
-    monkeypatch.setattr(config.interpreters, "get_info", lambda *args: info)
+    monkeypatch.setattr(config.interpreters, "get_info", lambda *args, **kw: info)
     pytest.raises(tox.exception.InvocationError, venv.getsupportedinterpreter)
 
 
@@ -58,14 +62,14 @@ def test_create(monkeypatch, mocksession, newconfig):
     assert "virtualenv" == str(args[2])
     if sys.platform != "win32":
         # realpath is needed for stuff like the debian symlinks
-        assert py.path.local(sys.executable).realpath() \
-          == py.path.local(args[0]).realpath()
-        #assert Envconfig.toxworkdir in args
+        assert py.path.local(sys.executable).realpath() == py.path.local(args[0]).realpath()
+        # assert Envconfig.toxworkdir in args
         assert venv.getcommandpath("easy_install", cwd=py.path.local())
     interp = venv._getliveconfig().python
-    assert interp == venv.envconfig._basepython_info.executable
+    assert interp == venv.envconfig.python_info.executable
     assert venv.path_config.check(exists=False)
 
+
 @pytest.mark.skipif("sys.platform == 'win32'")
 def test_commandpath_venv_precendence(tmpdir, monkeypatch,
                                       mocksession, newconfig):
@@ -80,21 +84,6 @@ def test_commandpath_venv_precendence(tmpdir, monkeypatch,
     p = venv.getcommandpath("easy_install")
     assert py.path.local(p).relto(envconfig.envbindir), p
 
-def test_create_distribute(monkeypatch, mocksession, newconfig):
-    config = newconfig([], """
-        [testenv:py123]
-        distribute=False
-    """)
-    envconfig = config.envconfigs['py123']
-    venv = VirtualEnv(envconfig, session=mocksession)
-    assert venv.path == envconfig.envdir
-    assert not venv.path.check()
-    venv.create()
-    l = mocksession._pcalls
-    assert len(l) >= 1
-    args = l[0].args
-    assert "--distribute" not in map(str, args)
-    assert "--setuptools" in map(str, args)
 
 def test_create_sitepackages(monkeypatch, mocksession, newconfig):
     config = newconfig([], """
@@ -122,6 +111,7 @@ def test_create_sitepackages(monkeypatch, mocksession, newconfig):
     assert "--system-site-packages" not in map(str, args)
     assert "--no-site-packages" not in map(str, args)
 
+
 def test_install_deps_wildcard(newmocksession):
     mocksession = newmocksession([], """
         [tox]
@@ -144,8 +134,8 @@ def test_install_deps_wildcard(newmocksession):
     assert l[-1].cwd == venv.envconfig.config.toxinidir
     assert "pip" in str(args[0])
     assert args[1] == "install"
-    #arg = "--download-cache=" + str(venv.envconfig.downloadcache)
-    #assert arg in args[2:]
+    # arg = "--download-cache=" + str(venv.envconfig.downloadcache)
+    # assert arg in args[2:]
     args = [arg for arg in args if str(arg).endswith("dep1-1.1.zip")]
     assert len(args) == 1
 
@@ -158,7 +148,6 @@ def test_install_downloadcache(newmocksession, monkeypatch, tmpdir, envdc):
         monkeypatch.delenv("PIP_DOWNLOAD_CACHE", raising=False)
     mocksession = newmocksession([], """
         [testenv:py123]
-        distribute=True
         deps=
             dep1
             dep2
@@ -179,6 +168,7 @@ def test_install_downloadcache(newmocksession, monkeypatch, tmpdir, envdc):
     deps = list(filter(None, [x[1] for x in venv._getliveconfig().deps]))
     assert deps == ['dep1', 'dep2']
 
+
 def test_install_deps_indexserver(newmocksession):
     mocksession = newmocksession([], """
         [tox]
@@ -211,6 +201,7 @@ def test_install_deps_indexserver(newmocksession):
     assert "-i ABC" in args
     assert "dep3" in args
 
+
 def test_install_deps_pre(newmocksession):
     mocksession = newmocksession([], """
         [testenv]
@@ -230,6 +221,7 @@ def test_install_deps_pre(newmocksession):
     assert "--pre " in args
     assert "dep1" in args
 
+
 def test_installpkg_indexserver(newmocksession, tmpdir):
     mocksession = newmocksession([], """
         [tox]
@@ -245,6 +237,7 @@ def test_installpkg_indexserver(newmocksession, tmpdir):
     args = " ".join(l[0].args)
     assert "-i ABC" in args
 
+
 def test_install_recreate(newmocksession, tmpdir):
     pkg = tmpdir.ensure("package.tar.gz")
     mocksession = newmocksession(['--recreate'], """
@@ -258,20 +251,22 @@ def test_install_recreate(newmocksession, tmpdir):
     venv.update()
     mocksession.report.expect("verbosity0", "*recreate*")
 
+
 def test_test_hashseed_is_in_output(newmocksession):
-    original_make_hashseed = tox._config.make_hashseed
-    tox._config.make_hashseed = lambda: '123456789'
+    original_make_hashseed = tox.config.make_hashseed
+    tox.config.make_hashseed = lambda: '123456789'
     try:
         mocksession = newmocksession([], '''
             [testenv]
         ''')
     finally:
-        tox._config.make_hashseed = original_make_hashseed
+        tox.config.make_hashseed = original_make_hashseed
     venv = mocksession.getenv('python')
     venv.update()
     venv.test()
     mocksession.report.expect("verbosity0", "python runtests: PYTHONHASHSEED='123456789'")
 
+
 def test_test_runtests_action_command_is_in_output(newmocksession):
     mocksession = newmocksession([], '''
         [testenv]
@@ -282,6 +277,7 @@ def test_test_runtests_action_command_is_in_output(newmocksession):
     venv.test()
     mocksession.report.expect("verbosity0", "*runtests*commands?0? | echo foo bar")
 
+
 def test_install_error(newmocksession, monkeypatch):
     mocksession = newmocksession(['--recreate'], """
         [testenv]
@@ -294,6 +290,7 @@ def test_install_error(newmocksession, monkeypatch):
     mocksession.report.expect("error", "*not find*qwelkqw*")
     assert venv.status == "commands failed"
 
+
 def test_install_command_not_installed(newmocksession, monkeypatch):
     mocksession = newmocksession(['--recreate'], """
         [testenv]
@@ -305,6 +302,7 @@ def test_install_command_not_installed(newmocksession, monkeypatch):
     mocksession.report.expect("warning", "*test command found but not*")
     assert venv.status == 0
 
+
 def test_install_command_whitelisted(newmocksession, monkeypatch):
     mocksession = newmocksession(['--recreate'], """
         [testenv]
@@ -320,6 +318,7 @@ def test_install_command_whitelisted(newmocksession, monkeypatch):
                               invert=True)
     assert venv.status == "commands failed"
 
+
 @pytest.mark.skipif("not sys.platform.startswith('linux')")
 def test_install_command_not_installed_bash(newmocksession):
     mocksession = newmocksession(['--recreate'], """
@@ -357,6 +356,7 @@ def test_install_python3(tmpdir, newmocksession):
     for x in args:
         assert "--download-cache" not in args, args
 
+
 class TestCreationConfig:
 
     def test_basic(self, newconfig, mocksession, tmpdir):
@@ -452,36 +452,25 @@ class TestCreationConfig:
         venv = VirtualEnv(envconfig, session=mocksession)
         venv.update()
         cconfig = venv._getliveconfig()
-        cconfig.deps[:] = [("1"*32, "xyz.zip")]
+        cconfig.deps[:] = [("1" * 32, "xyz.zip")]
         cconfig.writeconfig(venv.path_config)
         mocksession._clearmocks()
         venv.update()
         mocksession.report.expect("*", "*recreate*")
 
-    def test_distribute_recreation(self, newconfig, mocksession):
-        config = newconfig([], "")
-        envconfig = config.envconfigs['python']
-        venv = VirtualEnv(envconfig, session=mocksession)
-        venv.update()
-        cconfig = venv._getliveconfig()
-        cconfig.distribute = True
-        cconfig.writeconfig(venv.path_config)
-        mocksession._clearmocks()
-        venv.update()
-        mocksession.report.expect("verbosity0", "*recreate*")
-
     def test_develop_recreation(self, newconfig, mocksession):
         config = newconfig([], "")
         envconfig = config.envconfigs['python']
         venv = VirtualEnv(envconfig, session=mocksession)
         venv.update()
         cconfig = venv._getliveconfig()
-        cconfig.develop = True
+        cconfig.usedevelop = True
         cconfig.writeconfig(venv.path_config)
         mocksession._clearmocks()
         venv.update()
         mocksession.report.expect("verbosity0", "*recreate*")
 
+
 class TestVenvTest:
 
     def test_patchPATH(self, newmocksession, monkeypatch):
@@ -497,14 +486,14 @@ class TestVenvTest:
         assert oldpath == "xyz"
         res = os.environ['PATH']
         assert res == "%s%sxyz" % (envconfig.envbindir, os.pathsep)
-        p = "xyz"+os.pathsep+str(envconfig.envbindir)
+        p = "xyz" + os.pathsep + str(envconfig.envbindir)
         monkeypatch.setenv("PATH", p)
         venv.patchPATH()
         res = os.environ['PATH']
-        assert res == "%s%s%s" %(envconfig.envbindir, os.pathsep, p)
+        assert res == "%s%s%s" % (envconfig.envbindir, os.pathsep, p)
 
         assert envconfig.commands
-        monkeypatch.setattr(venv, '_pcall', lambda *args, **kwargs: 0/0)
+        monkeypatch.setattr(venv, '_pcall', lambda *args, **kwargs: 0 / 0)
         py.test.raises(ZeroDivisionError, "venv._install(list('123'))")
         py.test.raises(ZeroDivisionError, "venv.test()")
         py.test.raises(ZeroDivisionError, "venv.run_install_command(['qwe'])")
@@ -517,11 +506,14 @@ class TestVenvTest:
         assert 'PIP_REQUIRE_VIRTUALENV' not in os.environ
         assert '__PYVENV_LAUNCHER__' not in os.environ
 
-def test_setenv_added_to_pcall(tmpdir, mocksession, newconfig):
+
+def test_env_variables_added_to_pcall(tmpdir, mocksession, newconfig, monkeypatch):
     pkg = tmpdir.ensure("package.tar.gz")
+    monkeypatch.setenv("X123", "123")
     config = newconfig([], """
         [testenv:python]
         commands=python -V
+        passenv = x123
         setenv =
             ENV_VAR = value
     """)
@@ -540,9 +532,14 @@ def test_setenv_added_to_pcall(tmpdir, mocksession, newconfig):
         assert 'ENV_VAR' in env
         assert env['ENV_VAR'] == 'value'
         assert env['VIRTUAL_ENV'] == str(venv.path)
+        assert env['X123'] == "123"
+
+    assert set(["ENV_VAR", "VIRTUAL_ENV", "PYTHONHASHSEED", "X123", "PATH"])\
+        .issubset(env)
+
+    # for e in os.environ:
+    #    assert e in env
 
-    for e in os.environ:
-        assert e in env
 
 def test_installpkg_no_upgrade(tmpdir, newmocksession):
     pkg = tmpdir.ensure("package.tar.gz")
@@ -555,6 +552,7 @@ def test_installpkg_no_upgrade(tmpdir, newmocksession):
     assert len(l) == 1
     assert '-U' not in l[0].args
 
+
 def test_installpkg_upgrade(newmocksession, tmpdir):
     pkg = tmpdir.ensure("package.tar.gz")
     mocksession = newmocksession([], "")
@@ -568,6 +566,7 @@ def test_installpkg_upgrade(newmocksession, tmpdir):
     assert '-U' in l[0].args[:index]
     assert '--no-deps' in l[0].args[:index]
 
+
 def test_run_install_command(newmocksession):
     mocksession = newmocksession([], "")
     venv = mocksession.getenv('python')
@@ -582,6 +581,7 @@ def test_run_install_command(newmocksession):
     env = l[0].env
     assert env is not None
 
+
 def test_run_custom_install_command(newmocksession):
     mocksession = newmocksession([], """
         [testenv]
@@ -597,6 +597,7 @@ def test_run_custom_install_command(newmocksession):
     assert 'easy_install' in l[0].args[0]
     assert l[0].args[1:] == ['whatever']
 
+
 def test_command_relative_issue26(newmocksession, tmpdir, monkeypatch):
     mocksession = newmocksession([], """
         [testenv]
@@ -614,13 +615,15 @@ def test_command_relative_issue26(newmocksession, tmpdir, monkeypatch):
     assert x4.endswith(os.sep + 'x')
     mocksession.report.expect("warning", "*test command found but not*")
 
+
 def test_sethome_only_on_option(newmocksession, monkeypatch):
     mocksession = newmocksession([], "")
     venv = mocksession.getenv('python')
     action = mocksession.newaction(venv, "qwe", [])
-    monkeypatch.setattr(tox._venv, "hack_home_env", None)
+    monkeypatch.setattr(tox.venv, "hack_home_env", None)
     venv._install(["x"], action=action)
 
+
 def test_sethome_works_on_option(newmocksession, monkeypatch):
     mocksession = newmocksession(["--set-home", "-i ALL=http://qwe"], "")
     venv = mocksession.getenv('python')
@@ -633,7 +636,7 @@ def test_sethome_works_on_option(newmocksession, monkeypatch):
 
 
 def test_hack_home_env(tmpdir):
-    from tox._venv import hack_home_env
+    from tox.venv import hack_home_env
     env = hack_home_env(tmpdir, "http://index")
     assert env["HOME"] == str(tmpdir)
     assert env["PIP_INDEX_URL"] == "http://index"
@@ -645,8 +648,9 @@ def test_hack_home_env(tmpdir):
     assert not tmpdir.join(".pydistutils.cfg").check()
     assert "PIP_INDEX_URL" not in env
 
+
 def test_hack_home_env_passthrough(tmpdir, monkeypatch):
-    from tox._venv import hack_home_env
+    from tox.venv import hack_home_env
     env = hack_home_env(tmpdir, "http://index")
     monkeypatch.setattr(os, "environ", env)
 
