@@ -9,38 +9,43 @@ except ImportError:
 
 pytest_plugins = "pytester"
 
-from tox._cmdline import Session
-from tox._config import parseconfig
+from tox.session import Session
+from tox.config import parseconfig
+
 
 def test_report_protocol(newconfig):
     config = newconfig([], """
             [testenv:mypython]
             deps=xy
     """)
+
     class Popen:
         def __init__(self, *args, **kwargs):
             pass
+
         def communicate(self):
             return "", ""
+
         def wait(self):
             pass
 
     session = Session(config, popen=Popen,
-            Report=ReportExpectMock)
+                      Report=ReportExpectMock)
     report = session.report
     report.expect("using")
     venv = session.getvenv("mypython")
     venv.update()
     report.expect("logpopen")
 
+
 def test__resolve_pkg(tmpdir, mocksession):
     distshare = tmpdir.join("distshare")
     spec = distshare.join("pkg123-*")
     py.test.raises(tox.exception.MissingDirectory,
-        'mocksession._resolve_pkg(spec)')
+                   'mocksession._resolve_pkg(spec)')
     distshare.ensure(dir=1)
     py.test.raises(tox.exception.MissingDependency,
-        'mocksession._resolve_pkg(spec)')
+                   'mocksession._resolve_pkg(spec)')
     distshare.ensure("pkg123-1.3.5.zip")
     p = distshare.ensure("pkg123-1.4.5.zip")
 
@@ -58,6 +63,7 @@ def test__resolve_pkg(tmpdir, mocksession):
     result = mocksession._resolve_pkg(spec)
     assert result == p
 
+
 def test__resolve_pkg_doubledash(tmpdir, mocksession):
     distshare = tmpdir.join("distshare")
     p = distshare.ensure("pkg-mine-1.3.0.zip")
@@ -68,7 +74,6 @@ def test__resolve_pkg_doubledash(tmpdir, mocksession):
     assert res == p
 
 
-
 class TestSession:
     def test_make_sdist(self, initproj):
         initproj("example123-0.5", filedefs={
@@ -78,15 +83,15 @@ class TestSession:
         })
         config = parseconfig([])
         session = Session(config)
-        sdist = session.sdist()
+        sdist = session.get_installpkg_path()
         assert sdist.check()
         assert sdist.ext == ".zip"
         assert sdist == config.distdir.join(sdist.basename)
-        sdist2 = session.sdist()
+        sdist2 = session.get_installpkg_path()
         assert sdist2 == sdist
         sdist.write("hello")
         assert sdist.stat().size < 10
-        sdist_new = Session(config).sdist()
+        sdist_new = Session(config).get_installpkg_path()
         assert sdist_new == sdist
         assert sdist_new.stat().size > 10
 
@@ -101,7 +106,7 @@ class TestSession:
         })
         config = parseconfig([])
         session = Session(config)
-        sdist = session.sdist()
+        sdist = session.get_installpkg_path()
         assert sdist.check()
         assert sdist.ext == ".zip"
         assert sdist == config.distdir.join(sdist.basename)
@@ -116,7 +121,7 @@ class TestSession:
         action.popen(["echo", ])
         match = mocksession.report.getnext("logpopen")
         assert match[1].outpath.relto(mocksession.config.logdir)
-        assert match[1].shell == False
+        assert match[1].shell is False
 
     def test_summary_status(self, initproj, capfd):
         initproj("logexample123-0.5", filedefs={
@@ -177,6 +182,7 @@ def XXX_test_package(cmd, initproj):
         "*created sdist package at*",
     ])
 
+
 def test_minversion(cmd, initproj):
     initproj("interp123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -191,6 +197,7 @@ def test_minversion(cmd, initproj):
     ])
     assert result.ret
 
+
 def test_run_custom_install_command_error(cmd, initproj):
     initproj("interp123-0.5", filedefs={
         'tox.ini': '''
@@ -204,6 +211,7 @@ def test_run_custom_install_command_error(cmd, initproj):
     ])
     assert result.ret
 
+
 def test_unknown_interpreter_and_env(cmd, initproj):
     initproj("interp123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -226,6 +234,7 @@ def test_unknown_interpreter_and_env(cmd, initproj):
         "*ERROR*unknown*",
     ])
 
+
 def test_unknown_interpreter(cmd, initproj):
     initproj("interp123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -242,6 +251,26 @@ def test_unknown_interpreter(cmd, initproj):
         "*ERROR*InterpreterNotFound*xyz_unknown_interpreter*",
     ])
 
+
+def test_skip_platform_mismatch(cmd, initproj):
+    initproj("interp123-0.5", filedefs={
+        'tests': {'test_hello.py': "def test_hello(): pass"},
+        'tox.ini': '''
+            [testenv]
+            changedir=tests
+            platform=x123
+        '''
+    })
+    result = cmd.run("tox")
+    assert not result.ret
+    assert "platform mismatch" not in result.stdout.str()
+    result = cmd.run("tox", "-v")
+    assert not result.ret
+    result.stdout.fnmatch_lines([
+        "*python*platform mismatch*"
+    ])
+
+
 def test_skip_unknown_interpreter(cmd, initproj):
     initproj("interp123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -258,6 +287,7 @@ def test_skip_unknown_interpreter(cmd, initproj):
         "*SKIPPED*InterpreterNotFound*xyz_unknown_interpreter*",
     ])
 
+
 def test_unknown_dep(cmd, initproj):
     initproj("dep123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -273,6 +303,7 @@ def test_unknown_dep(cmd, initproj):
         "*ERROR*could not install*qweqwe123*",
     ])
 
+
 def test_unknown_environment(cmd, initproj):
     initproj("env123-0.7", filedefs={
         'tox.ini': ''
@@ -283,13 +314,13 @@ def test_unknown_environment(cmd, initproj):
         "*ERROR*unknown*environment*qpwoei*",
     ])
 
+
 def test_skip_sdist(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
         'setup.py': """
             syntax error
-        """
-        ,
+        """,
         'tox.ini': '''
             [tox]
             skipsdist=True
@@ -300,12 +331,12 @@ def test_skip_sdist(cmd, initproj):
     result = cmd.run("tox", )
     assert result.ret == 0
 
+
 def test_minimal_setup_py_empty(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
         'setup.py': """
-        """
-        ,
+        """,
         'tox.ini': ''
 
     })
@@ -315,13 +346,13 @@ def test_minimal_setup_py_empty(cmd, initproj):
         "*ERROR*empty*",
     ])
 
+
 def test_minimal_setup_py_comment_only(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
         'setup.py': """\n# some comment
 
-        """
-        ,
+        """,
         'tox.ini': ''
 
     })
@@ -331,14 +362,14 @@ def test_minimal_setup_py_comment_only(cmd, initproj):
         "*ERROR*empty*",
     ])
 
+
 def test_minimal_setup_py_non_functional(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
         'setup.py': """
         import sys
 
-        """
-        ,
+        """,
         'tox.ini': ''
 
     })
@@ -348,13 +379,13 @@ def test_minimal_setup_py_non_functional(cmd, initproj):
         "*ERROR*check setup.py*",
     ])
 
+
 def test_sdist_fails(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
         'setup.py': """
             syntax error
-        """
-        ,
+        """,
         'tox.ini': '',
     })
     result = cmd.run("tox", )
@@ -363,6 +394,7 @@ def test_sdist_fails(cmd, initproj):
         "*FAIL*could not package project*",
     ])
 
+
 def test_package_install_fails(cmd, initproj):
     initproj("pkg123-0.7", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
@@ -377,8 +409,7 @@ def test_package_install_fails(cmd, initproj):
                 packages=['pkg123',],
                 install_requires=['qweqwe123'],
                 )
-            """
-        ,
+            """,
         'tox.ini': '',
     })
     result = cmd.run("tox", )
@@ -388,14 +419,14 @@ def test_package_install_fails(cmd, initproj):
     ])
 
 
-
 class TestToxRun:
     @pytest.fixture
     def example123(self, initproj):
         initproj("example123-0.5", filedefs={
-            'tests': {'test_hello.py': """
-                def test_hello(pytestconfig):
-                    pass
+            'tests': {
+                'test_hello.py': """
+                    def test_hello(pytestconfig):
+                        pass
                 """,
             },
             'tox.ini': '''
@@ -457,6 +488,7 @@ def test_develop(initproj, cmd):
     assert not result.ret
     assert "sdist-make" not in result.stdout.str()
 
+
 def test_usedevelop(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
             [testenv]
@@ -466,6 +498,7 @@ def test_usedevelop(initproj, cmd):
     assert not result.ret
     assert "sdist-make" not in result.stdout.str()
 
+
 def test_usedevelop_mixed(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
             [testenv:devenv]
@@ -484,11 +517,13 @@ def test_usedevelop_mixed(initproj, cmd):
     assert not result.ret
     assert "sdist-make" in result.stdout.str()
 
+
 def test_test_usedevelop(cmd, initproj):
     initproj("example123-0.5", filedefs={
-        'tests': {'test_hello.py': """
-            def test_hello(pytestconfig):
-                pass
+        'tests': {
+            'test_hello.py': """
+                def test_hello(pytestconfig):
+                    pass
             """,
         },
         'tox.ini': '''
@@ -550,6 +585,7 @@ def test_test_piphelp(initproj, cmd):
     result = cmd.run("tox")
     assert not result.ret
 
+
 def test_notest(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
         # content of: tox.ini
@@ -568,6 +604,7 @@ def test_notest(initproj, cmd):
         "*py26*reusing*",
     ])
 
+
 def test_PYC(initproj, cmd, monkeypatch):
     initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("PYTHONDOWNWRITEBYTECODE", 1)
@@ -577,6 +614,7 @@ def test_PYC(initproj, cmd, monkeypatch):
         "*create*",
     ])
 
+
 def test_env_VIRTUALENV_PYTHON(initproj, cmd, monkeypatch):
     initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("VIRTUALENV_PYTHON", '/FOO')
@@ -586,6 +624,7 @@ def test_env_VIRTUALENV_PYTHON(initproj, cmd, monkeypatch):
         "*create*",
     ])
 
+
 def test_sdistonly(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
     """})
@@ -596,6 +635,7 @@ def test_sdistonly(initproj, cmd):
     ])
     assert "-mvirtualenv" not in result.stdout.str()
 
+
 def test_separate_sdist_no_sdistfile(cmd, initproj):
     distshare = cmd.tmpdir.join("distshare")
     initproj(("pkg123-foo", "0.7"), filedefs={
@@ -611,6 +651,7 @@ def test_separate_sdist_no_sdistfile(cmd, initproj):
     sdistfile = l[0]
     assert 'pkg123-foo-0.7.zip' in str(sdistfile)
 
+
 def test_separate_sdist(cmd, initproj):
     distshare = cmd.tmpdir.join("distshare")
     initproj("pkg123-0.7", filedefs={
@@ -642,16 +683,18 @@ def test_sdist_latest(tmpdir, newconfig):
     p = distshare.ensure("pkg123-1.4.5.zip")
     distshare.ensure("pkg123-1.4.5a1.zip")
     session = Session(config)
-    sdist_path = session.sdist()
+    sdist_path = session.get_installpkg_path()
     assert sdist_path == p
 
+
 def test_installpkg(tmpdir, newconfig):
     p = tmpdir.ensure("pkg123-1.0.zip")
     config = newconfig(["--installpkg=%s" % p], "")
     session = Session(config)
-    sdist_path = session.sdist()
+    sdist_path = session.get_installpkg_path()
     assert sdist_path == p
 
+
 @pytest.mark.xfail("sys.platform == 'win32' and sys.version_info < (2,6)",
                    reason="test needs better impl")
 def test_envsitepackagesdir(cmd, initproj):
@@ -667,6 +710,7 @@ def test_envsitepackagesdir(cmd, initproj):
         X:*tox*site-packages*
     """)
 
+
 def verify_json_report_format(data, testenvs=True):
     assert data["reportversion"] == "1"
     assert data["toxversion"] == tox.__version__
@@ -678,8 +722,9 @@ def verify_json_report_format(data, testenvs=True):
                 for command in envdata[commandtype]:
                     assert command["output"]
                     assert command["retcode"]
-            pyinfo = envdata["python"]
-            assert isinstance(pyinfo["version_info"], list)
-            assert pyinfo["version"]
-            assert pyinfo["executable"]
-
+            if envname != "GLOB":
+                assert isinstance(envdata["installed_packages"], list)
+                pyinfo = envdata["python"]
+                assert isinstance(pyinfo["version_info"], list)
+                assert pyinfo["version"]
+                assert pyinfo["executable"]
