@@ -1,10 +1,14 @@
 #
-__version__ = '1.9.2'
+__version__ = '2.0.1'
+
+from .hookspecs import hookspec, hookimpl  # noqa
+
 
 class exception:
     class Error(Exception):
         def __str__(self):
-            return "%s: %s" %(self.__class__.__name__, self.args[0])
+            return "%s: %s" % (self.__class__.__name__, self.args[0])
+
     class ConfigError(Error):
         """ error in tox configuration. """
     class UnsupportedInterpreter(Error):
@@ -20,4 +24,4 @@ class exception:
     class MissingDependency(Error):
         """ a dependency could not be found or determined. """
 
-from tox._cmdline import main as cmdline  # noqa
+from tox.session import main as cmdline  # noqa
